diff --git a/jOOQ/src/main/java/org/jooq/tools/Convert.java b/jOOQ/src/main/java/org/jooq/tools/Convert.java
index 7ae73dba6d..32b9f3058e 100644
--- a/jOOQ/src/main/java/org/jooq/tools/Convert.java
+++ b/jOOQ/src/main/java/org/jooq/tools/Convert.java
@@ -49,6 +49,7 @@ import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Calendar;
+import java.util.Collection;
import java.util.Collections;
import java.util.HashSet;
import java.util.List;
@@ -259,41 +260,41 @@ public final class Convert {
}
/**
* Convert a list of objects to a list of T, using
* {@link #convert(Object, Class)}
*
* @param list The list of objects
* @param type The target type
* @return The list of converted objects
* @throws DataTypeException - When the conversion is not possible
* @see #convert(Object, Class)
*/
- public static List convert(List> list, Class extends T> type) throws DataTypeException {
- return convert(list, new ConvertAll(type));
+ public static List convert(Collection> collection, Class extends T> type) throws DataTypeException {
+ return convert(collection, new ConvertAll(type));
}
/**
* Convert a list of objects to a list of T, using
* {@link #convert(Object, Converter)}
*
* @param list The list of objects
* @param converter The data type converter
* @return The list of converted objects
* @throws DataTypeException - When the conversion is not possible
* @see #convert(Object, Converter)
*/
- public static List convert(List> list, Converter, U> converter) throws DataTypeException {
- return convert0(list, converter);
+ public static List convert(Collection> collection, Converter, U> converter) throws DataTypeException {
+ return convert0(collection, converter);
}
/**
* Type safe conversion
*/
- private static List convert0(List> list, Converter converter) throws DataTypeException {
+ private static List convert0(Collection> collection, Converter converter) throws DataTypeException {
ConvertAll all = new ConvertAll(converter.fromType());
- List result = new ArrayList(list.size());
+ List result = new ArrayList(collection.size());
- for (Object o : list) {
+ for (Object o : collection) {
result.add(convert(all.from(o), converter));
}
@@ -259,41 +260,41 @@ public final class Convert {
}
/**
- * Convert a list of objects to a list of T, using
+ * Convert a collection of objects to a list of T, using
* {@link #convert(Object, Class)}
*
@@ -259,41 +260,41 @@ public final class Convert {
* {@link #convert(Object, Class)}
*
- * @param list The list of objects
+ * @param collection The list of objects
* @param type The target type
* @return The list of converted objects
@@ -259,41 +260,41 @@ public final class Convert {
}
/**
- * Convert a list of objects to a list of T, using
+ * Convert a collection of objects to a list of T, using
* {@link #convert(Object, Converter)}
*
@@ -259,41 +260,41 @@ public final class Convert {
* {@link #convert(Object, Converter)}
*
- * @param list The list of objects
+ * @param collection The collection of objects
* @param converter The data type converter
* @return The list of converted objects